@@ -77,6 +77,7 @@
 #define CURLE_GOT_NOTHING_FIRST 0x070901 /* Added in 7.9.1 */
 #define CURLE_HTTP2_FIRST 0x072600 /* Added in 7.38.0 */
 #define CURLE_HTTP2_STREAM_FIRST 0x073100 /* Added in 7.49.0 */
+#define CURLE_HTTP3_FIRST 0x074400 /* Added in 7.68.0 */
 #define CURLE_HTTP_NOT_FOUND_FIRST 0x070100 /* Added in 7.1 */
 #define CURLE_HTTP_PORT_FAILED_FIRST 0x070300 /* Added in 7.3 */
 #define CURLE_HTTP_POST_ERROR_FIRST 0x070100 /* Added in 7.1 */
@@ -314,6 +315,7 @@
 #define CURLMOPT_MAX_HOST_CONNECTIONS_FIRST 0x071e00 /* Added in 7.30.0 */
 #define CURLMOPT_MAX_PIPELINE_LENGTH_FIRST 0x071e00 /* Added in 7.30.0 */
 #define CURLMOPT_MAX_TOTAL_CONNECTIONS_FIRST 0x071e00 /* Added in 7.30.0 */
+#define CURLMOPT_MAX_CONCURRENT_STREAMS_FIRST 0x074300 /* Added in 7.67.0 */
 #define CURLMOPT_PIPELINING_FIRST 0x071000 /* Added in 7.16.0 */
 #define CURLMOPT_PIPELINING_SERVER_BL_FIRST 0x071e00 /* Added in 7.30.0 */
 #define CURLMOPT_PIPELINING_SITE_BL_FIRST 0x071e00 /* Added in 7.30.0 */
@@ -335,6 +337,7 @@
 #define CURLM_OK_FIRST 0x070906 /* Added in 7.9.6 */
 #define CURLM_OUT_OF_MEMORY_FIRST 0x070906 /* Added in 7.9.6 */
 #define CURLM_RECURSIVE_API_CALL_FIRST 0x073b00 /* Added in 7.59.0 */
+#define CURLM_WAKEUP_FAILURE_FIRST 0x074400 /* Added in 7.68.0 */
 #define CURLM_UNKNOWN_OPTION_FIRST 0x070f04 /* Added in 7.15.4 */
 #define CURLOPTTYPE_FUNCTIONPOINT_FIRST 0x070100 /* Added in 7.1 */
 #define CURLOPTTYPE_LONG_FIRST 0x070100 /* Added in 7.1 */
@@ -728,6 +731,7 @@
 #define CURLSSH_AUTH_PASSWORD_FIRST 0x071001 /* Added in 7.16.1 */
 #define CURLSSH_AUTH_PUBLICKEY_FIRST 0x071001 /* Added in 7.16.1 */
 #define CURLSSLBACKEND_AXTLS_FIRST 0x072600 /* Added in 7.38.0 */
+#define CURLSSLBACKEND_BEARSSL_FIRST 0x074400 /* Added in 7.68.0 */
 #define CURLSSLBACKEND_BORINGSSL_FIRST 0x073100 /* Added in 7.49.0 */
 #define CURLSSLBACKEND_CYASSL_FIRST 0x072200 /* Added in 7.34.0 */
 #define CURLSSLBACKEND_DARWINSSL_FIRST 0x072200 /* Added in 7.34.0 */
@@ -746,6 +750,7 @@
 #define CURLSSLBACKEND_SECURETRANSPORT_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLSSLBACKEND_WOLFSSL_FIRST 0x073100 /* Added in 7.49.0 */
 #define CURLSSLOPT_ALLOW_BEAST_FIRST 0x071900 /* Added in 7.25.0 */
+#define CURLSSLOPT_NO_PARTIALCHAIN_FIRST 0x074400 /* Added in 7.68.0 */
 #define CURLSSLOPT_NO_REVOKE_FIRST 0x072c00 /* Added in 7.44.0 */
 #define CURLSSLSET_NO_BACKENDS_FIRST 0x073800 /* Added in 7.56.0 */
 #define CURLSSLSET_OK_FIRST 0x073800 /* Added in 7.56.0 */
@@ -791,6 +796,7 @@
 #define CURLU_GUESS_SCHEME_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_NON_SUPPORT_SCHEME_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_NO_DEFAULT_PORT_FIRST 0x073e00 /* Added in 7.62.0 */
+#define CURLU_NO_AUTHORITY_FIRST 0x074300 /* Added in 7.67.0 */
 #define CURLU_PATH_AS_IS_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_URLDECODE_FIRST 0x073e00 /* Added in 7.62.0 */
 #define CURLU_URLENCODE_FIRST 0x073e00 /* Added in 7.62.0 */
@@ -883,6 +889,7 @@
 #define CURL_POLL_NONE_FIRST 0x070e00 /* Added in 7.14.0 */
 #define CURL_POLL_OUT_FIRST 0x070e00 /* Added in 7.14.0 */
 #define CURL_POLL_REMOVE_FIRST 0x070e00 /* Added in 7.14.0 */
+#define CURL_PROGRESSFUNC_CONTINUE_FIRST 0x074400 /* Added in 7.68.0 */
 #define CURL_PROGRESS_BAR_FIRST 0x070101 /* Added in 7.1.1 */
 #define CURL_PROGRESS_BAR_LAST 0x070401 /* Last featured in 7.4.1 */
 #define CURL_PROGRESS_STATS_FIRST 0x070101 /* Added in 7.1.1 */
@@ -946,6 +953,7 @@
 #define CURL_VERSION_CONV_FIRST 0x070f04 /* Added in 7.15.4 */
 #define CURL_VERSION_CURLDEBUG_FIRST 0x071306 /* Added in 7.19.6 */
 #define CURL_VERSION_DEBUG_FIRST 0x070a06 /* Added in 7.10.6 */
+#define CURL_VERSION_ESNI_FIRST 0x074300 /* Added in 7.67.0 */
 #define CURL_VERSION_GSSAPI_FIRST 0x072600 /* Added in 7.38.0 */
 #define CURL_VERSION_GSSNEGOTIATE_FIRST 0x070a06 /* Added in 7.10.6 */
 #define CURL_VERSION_HTTP2_FIRST 0x072100 /* Added in 7.33.0 */
